==> acld-0.1a15.tar.gz: acld-0.1a15/acl.h <==
/* @(#) $Id: acl.h,v 1.16 2004/08/09 20:28:31 leres Exp $ (LBL) */
#ifndef acld_acl_h
#define acld_acl_h

/* address */
struct addr {
	u_int32_t addr;
	u_int32_t mask;
};

/*
 * The normal case when blocking hosts or nets is "source"
 * The normal case when blocking ports is "dest"
 * If we're doing something else, we specify
 */
enum acltype {
	ATYPE_UNKNOWN = 0,
	ATYPE_PERMITANY,		/* allow everything */
	ATYPE_BLOCKANY,			/* block everything */

	ATYPE_PERMITHOST,		/* permit a src-host */
	ATYPE_BLOCKHOST,		/* block a src-host */

	ATYPE_PERMITNET,		/* permit a src-network */
	ATYPE_BLOCKNET,			/* block a src-network */

	ATYPE_PERMITUDPPORT,		/* permit a dst-udp port */
	ATYPE_BLOCKUDPPORT,		/* block a dst-udp port */
	ATYPE_PERMITTCPPORT,		/* permit a dst-tcp port */
	ATYPE_BLOCKTCPPORT,		/* block a dst-tcp port */

	ATYPE_PERMITUDPDSTHOST,		/* permit a dst-udp-host */
	ATYPE_BLOCKUDPDSTHOST,		/* block a dst-udp-host */
	ATYPE_PERMITTCPDSTHOST,		/* permit a dst-tcp-host */
	ATYPE_BLOCKTCPDSTHOST,		/* block a dst-tcp-host */

	ATYPE_PERMITIPDSTHOST,		/* permit a dst-ip-host */
	ATYPE_BLOCKIPDSTHOST,		/* block a dst-ip-host */
	ATYPE_PERMITICMPDSTHOST,	/* permit a dst-icmp-host */
	ATYPE_BLOCKICMPDSTHOST,		/* block a dst-icmp-host */

	ATYPE_PERMITIPDSTNET,		/* permit a dst-ip-net */
	ATYPE_BLOCKIPDSTNET,		/* block a dst-ip-net */
	ATYPE_PERMITICMPDSTNET,		/* permit a dst-icmp-net */
	ATYPE_BLOCKICMPDSTNET,		/* block a dst-icmp-net */

	ATYPE_PERMITUDPHOSTPORT,	/* permit a src-host/dst-udp port */
	ATYPE_BLOCKUDPHOSTPORT,		/* block a src-host/dst-udp port */
	ATYPE_PERMITTCPHOSTPORT,	/* permit a src-host/dst-tcp port */
	ATYPE_BLOCKTCPHOSTPORT,		/* block a src-host/dst-tcp port */

	ATYPE_PERMITUDPDSTHOSTPORT,	/* permit a dst-host/dst-udp port */
	ATYPE_BLOCKUDPDSTHOSTPORT,	/* block a dst-host/dst-udp port */
	ATYPE_PERMITTCPDSTHOSTPORT,	/* permit a dst-host/dst-tcp port */
	ATYPE_BLOCKTCPDSTHOSTPORT,	/* block a dst-host/dst-tcp port */

	ATYPE_PERMITUDPNETPORT,		/* permit a src-network/dst-udp port */
	ATYPE_BLOCKUDPNETPORT,		/* block a src-network/dst-udp port */
	ATYPE_PERMITTCPNETPORT,		/* permit a src-network/dst-tcp port */
	ATYPE_BLOCKTCPNETPORT,		/* block a src-network/dst-tcp port */

	ATYPE_PERMITUDPHOSTSRCPORT,	/* permit a src-host/src-udp port */
	ATYPE_BLOCKUDPHOSTSRCPORT,	/* block a src-host/src-udp port */
	ATYPE_PERMITTCPHOSTSRCPORT,	/* permit a src-host/src-tcp port */
	ATYPE_BLOCKTCPHOSTSRCPORT,	/* block a src-host/src-tcp port */

	ATYPE_PERMITUDPHOSTPAIRDSTPORT,	/* permit a host pair/dst-udp port */
	ATYPE_BLOCKUDPHOSTPAIRDSTPORT,	/* block a host pair/dst-udp port */
	ATYPE_PERMITTCPHOSTPAIRDSTPORT,	/* permit a host pair/dst-tcp port */
	ATYPE_BLOCKTCPHOSTPAIRDSTPORT	/* block a host pair/dst-tcp port */
};

/* ACL */
struct acl {
	enum acltype type;
	int seq;			/* sequence number */
	int count;
	struct addr addr1;
	struct addr addr2;
	char *port1;
	char *port2;
	char *raw;			/* text as returned from the router */
};

#define ISDEFAULTADDR(a) ((a)->addr == 0 && (a)->mask == 0xffffffff)

/* ACL list */
struct acllist {
	char *name;
	int sentlistacl;
	struct acl *acl;
	int acllen;
	int aclsize;
	int lastseq;
	int lastportseq;
	int compactseq;
	struct client *compactclient;
	struct req *compactreq;
	struct addr *addr;
	int addrlen;
	int addrsize;
	struct intlist *intlist;
};

void acladdacl(struct acllist *, struct acl *);
void acladdacllist(struct cf *, const char *);
int acldeleteacl(struct acllist *, struct acl *);
struct acl *aclfindacl(struct acllist *, struct acl *);
struct acllist *aclfindlistbyaddr(struct cf *, struct addr *);
struct acllist *aclfindlistbyname(struct cf *, const char *);
const char *aclformat(struct acl *);
void aclfree(struct acllist *);
void acllistsfree(struct state *);
void aclsortacls(struct cf *);
int aclstraddacl(struct cf *, struct acllist *, const char *);
#endif

==> acld-0.3.1.tar.gz: acld-0.3.1/acl.h <==
/* @(#) $Id: acl.h 547 2009-01-23 03:46:59Z leres $ (LBL) */
#ifndef acld_acl_h
#define acld_acl_h

/* address */
struct addr {
	u_int32_t addr;
	u_int32_t mask;
};

/*
 * The normal case when blocking hosts or nets is "source"
 * The normal case when blocking ports is "dest"
 * If we're doing something else, we specify
 */
enum acltype {
	ATYPE_UNKNOWN = 0,
	ATYPE_PERMITANY,		/* allow everything */
	ATYPE_BLOCKANY,			/* block everything */

	ATYPE_PERMITHOST,		/* permit a src-host */
	ATYPE_BLOCKHOST,		/* block a src-host */

	ATYPE_PERMITHOSTHOST,		/* permit a host to host */
	ATYPE_BLOCKHOSTHOST,		/* block a host to host */

	ATYPE_PERMITNET,		/* permit a src-network */
	ATYPE_BLOCKNET,			/* block a src-network */

	ATYPE_PERMITIPNETHOST,		/* permit a src-ip-network-host */
	ATYPE_BLOCKIPNETHOST,		/* block a src-ip-network-host */

	ATYPE_PERMITUDPPORT,		/* permit a dst-udp port */
	ATYPE_BLOCKUDPPORT,		/* block a dst-udp port */
	ATYPE_PERMITTCPPORT,		/* permit a dst-tcp port */
	ATYPE_BLOCKTCPPORT,		/* block a dst-tcp port */

	ATYPE_PERMITUDPDSTHOST,		/* permit a dst-udp-host */
	ATYPE_BLOCKUDPDSTHOST,		/* block a dst-udp-host */
	ATYPE_PERMITTCPDSTHOST,		/* permit a dst-tcp-host */
	ATYPE_BLOCKTCPDSTHOST,		/* block a dst-tcp-host */

	ATYPE_PERMITIPDSTHOST,		/* permit a dst-ip-host */
	ATYPE_BLOCKIPDSTHOST,		/* block a dst-ip-host */
	ATYPE_PERMITICMPDSTHOST,	/* permit a dst-icmp-host */
	ATYPE_BLOCKICMPDSTHOST,		/* block a dst-icmp-host */

	ATYPE_PERMITIPDSTNET,		/* permit a dst-ip-net */
	ATYPE_BLOCKIPDSTNET,		/* block a dst-ip-net */
	ATYPE_PERMITICMPDSTNET,		/* permit a dst-icmp-net */
	ATYPE_BLOCKICMPDSTNET,		/* block a dst-icmp-net */

	ATYPE_PERMITUDPHOSTPORT,	/* permit a src-host/dst-udp port */
	ATYPE_BLOCKUDPHOSTPORT,		/* block a src-host/dst-udp port */
	ATYPE_PERMITTCPHOSTPORT,	/* permit a src-host/dst-tcp port */
	ATYPE_BLOCKTCPHOSTPORT,		/* block a src-host/dst-tcp port */

	ATYPE_PERMITUDPDSTHOSTPORT,	/* permit a dst-host/dst-udp port */
	ATYPE_BLOCKUDPDSTHOSTPORT,	/* block a dst-host/dst-udp port */
	ATYPE_PERMITTCPDSTHOSTPORT,	/* permit a dst-host/dst-tcp port */
	ATYPE_BLOCKTCPDSTHOSTPORT,	/* block a dst-host/dst-tcp port */

	ATYPE_PERMITUDPNETPORT,		/* permit a src-network/dst-udp port */
	ATYPE_BLOCKUDPNETPORT,		/* block a src-network/dst-udp port */
	ATYPE_PERMITTCPNETPORT,		/* permit a src-network/dst-tcp port */
	ATYPE_BLOCKTCPNETPORT,		/* block a src-network/dst-tcp port */

	ATYPE_PERMITUDPHOSTSRCPORT,	/* permit a src-host/src-udp port */
	ATYPE_BLOCKUDPHOSTSRCPORT,	/* block a src-host/src-udp port */
	ATYPE_PERMITTCPHOSTSRCPORT,	/* permit a src-host/src-tcp port */
	ATYPE_BLOCKTCPHOSTSRCPORT,	/* block a src-host/src-tcp port */

	ATYPE_PERMITUDPHOSTPAIRDSTPORT,	/* permit a host pair/dst-udp port */
	ATYPE_BLOCKUDPHOSTPAIRDSTPORT,	/* block a host pair/dst-udp port */
	ATYPE_PERMITTCPHOSTPAIRDSTPORT,	/* permit a host pair/dst-tcp port */
	ATYPE_BLOCKTCPHOSTPAIRDSTPORT,	/* block a host pair/dst-tcp port */

	ATYPE_PERMITUDPDSTNET,		/* permit a udp-dst-net */
	ATYPE_BLOCKUDPDSTNET,		/* block a udp-dst-net */
	ATYPE_PERMITTCPDSTNET,		/* permit a tcp-dst-net */
	ATYPE_BLOCKTCPDSTNET,		/* block a tcp-dst-net */

	ATYPE_PERMITUDPNETHOSTPORT,	/* permit a udp-net-host-port */
	ATYPE_BLOCKUDPNETHOSTPORT,	/* block a udp-net-host-port */
	ATYPE_PERMITTCPNETHOSTPORT,	/* permit a tcp-net-host-port */
	ATYPE_BLOCKTCPNETHOSTPORT,	/* block a tcp-net-host-port */
};

/* ACL */
struct acl {
	enum acltype type;
	int seq;			/* sequence number */
	unsigned long long count;
	struct addr addr1;
	struct addr addr2;
	char *port1;
	char *port2;
	char *raw;			/* text as returned from the router */
};

#define ISDEFAULTADDR(a) ((a)->addr == 0 && (a)->mask == 0xffffffff)

/* ACL list */
struct acllist {
	char *name;
	int sentlistacl;
	struct acl *acl;
	size_t acllen;
	size_t aclsize;
	int lastseq;
	int lastportseq;
	int lastpermithostportseq;
	int compactseq;
	int compactportseq;
	int compactpermithostportseq;
	struct client *compactclient;
	struct req *compactreq;
	struct addr *addr;			/* used to choose acl list */
	size_t addrlen;
	size_t addrsize;
	struct intlist *intlist;
	struct stats stats;
};

extern struct s2v str2acl[];

void acladdacl(struct acllist *, struct acl *);
void acladdacllist(struct cf *, const char *);
int acldeleteacl(struct acllist *, struct acl *);
void aclcopy(struct acl *, const struct acl *);
struct acl *aclfindacl(struct acllist *, struct acl *);
struct acllist *aclfindlistbyaddr(struct cf *, struct addr *);
struct acllist *aclfindlistbyname(struct cf *, const char *);
const char *aclformat(struct acl *);
void aclfree(struct acllist *);
void acllistsfree(struct state *);
void aclsortacls(struct cf *);
int aclstraddacl(struct cf *, struct acllist *, const char *);
#endif
